<?php
/**
 * Perforce Swarm
 *
 * @copyright   2013-2019 Perforce Software. All rights reserved.
 * @license     Please see LICENSE.txt in top-level readme folder of this distribution.
 * @version     2019.1/1829459
 */

use Markdown\Settings as MarkdownSettings;

return array(
    'projects' => array(
        'mainlines'                  => array('main', 'mainline', 'master', 'trunk'),  // common mainline branch ids
        'add_admin_only'             => null,     // if enabled only admin users can create projects
        'add_groups_only'            => null,     // if set, only members of given groups can create projects
        'edit_name_admin_only'       => false,    // if enabled only admin users can edit project name
        'edit_branches_admin_only'   => false,    // if enabled only admin users can add/edit/remove project branches
        'private_by_default'         => false,    // if enabled then new projects will have 'private' option checked
        'max_readme_size'            => null,     // if enabled this will limit readme.md size. Size in Bytes.
        'readme_mode'                => MarkdownSettings::ENABLED, // Read me files allow markdown by default, the parse
                                                                   // level is defaulted in markdown->markdown (safe)
        'fetch'                      => array('maximum'=> 0) // 0 === get all projects, set to > 0 when there are lots
    ),
    'router' => array(
        'routes' => array(
            'project' => array(
                'type' => 'Zend\Router\Http\Segment',
                'options' => array(
                    'route'    => '/project[s]/:project[/]',
                    'defaults' => array(
                        'controller' => Projects\Controller\IndexController::class,
                        'action'     => 'project'
                    ),
                ),
            ),
            'add-project' => array(
                'type' => 'Zend\Router\Http\Segment',
                'options' => array(
                    'route'    => '/project[s]/add[/]',
                    'defaults' => array(
                        'controller' => Projects\Controller\IndexController::class,
                        'action'     => 'add',
                    ),
                ),
            ),
            'edit-project' => array(
                'type' => 'Zend\Router\Http\Segment',
                'options' => array(
                    'route'    => '/project[s]/edit/:project[/]',
                    'defaults' => array(
                        'controller' => Projects\Controller\IndexController::class,
                        'action'     => 'edit'
                    ),
                ),
            ),
            'delete-project' => array(
                'type' => 'Zend\Router\Http\Segment',
                'options' => array(
                    'route'    => '/project[s]/delete/:project[/]',
                    'defaults' => array(
                        'controller' => Projects\Controller\IndexController::class,
                        'action'     => 'delete'
                    ),
                ),
            ),
            'project-activity' => array(
                'type' => 'Zend\Router\Http\Segment',
                'options' => array(
                    'route'    => '/project[s]/:project/activity[/]',
                    'defaults' => array(
                        'controller' => Projects\Controller\IndexController::class,
                        'action'     => 'activity'
                    ),
                ),
            ),
            'project-reviews' => array(
                'type' => 'Zend\Router\Http\Segment',
                'options' => array(
                    'route'    => '/project[s]/:project/reviews[/]',
                    'defaults' => array(
                        'controller' => Projects\Controller\IndexController::class,
                        'action'     => 'reviews'
                    ),
                ),
            ),
            'project-jobs' => array(
                'type' => 'Application\Router\Regex',
                'options' => array(
                    'regex'    => '/projects?/(?P<project>.+)/jobs?(/(?P<job>.*))?',
                    'spec'     => '/projects/%project%/jobs/%job%',
                    'defaults' => array(
                        'controller' => Projects\Controller\IndexController::class,
                        'action'     => 'jobs',
                        'job'        => null
                    ),
                ),
            ),
            'project-browse' => array(
                'type' => 'Application\Router\Regex',
                'options' => array(
                    'regex'    => '/projects?/(?P<project>[^/]+)/'
                                . '(?P<mode>(files|view|download|changes))(/(?P<path>.*))?',
                    'spec'     => '/projects/%project%/%mode%/%path%',
                    'defaults' => array(
                        'controller' => Projects\Controller\IndexController::class,
                        'action'     => 'browse',
                        'path'       => null
                    ),
                ),
            ),
            'project-archive' => array(
                'type' => 'Application\Router\Regex',
                'options' => array(
                    'regex'    => '/projects?/(?P<project>[^/]+)/archives?/(?P<path>.+)\.zip',
                    'spec'     => '/projects/%project%/archives/%path%.zip',
                    'defaults' => array(
                        'controller' => Projects\Controller\IndexController::class,
                        'action'     => 'archive'
                    ),
                ),
            ),
            'projects' => array(
                'type' => 'Zend\Router\Http\Segment',
                'options' => array(
                    'route'    => '/projects[/]',
                    'defaults' => array(
                        'controller' => Projects\Controller\IndexController::class,
                        'action'     => 'projects'
                    ),
                ),
            ),
        ),
    ),
    'controllers' => array(
        'factories' => [
            Projects\Controller\IndexController::class => Application\Controller\IndexControllerFactory::class,
        ],
    ),
    'view_manager' => array(
        'template_map' => array(
            'projects/index/project'    => __DIR__ . '/../view/projects/index/project.phtml',
            'projects/index/add'        => __DIR__ . '/../view/projects/index/add.phtml',
            'projects/index/activity'   => __DIR__ . '/../view/projects/index/activity.phtml'
        ),
        'template_path_stack'   => array(
            __DIR__ . '/../view',
        ),
    ),
    'view_helpers' => array(
        'factories' => array_fill_keys(
            [
                Application\View\Helper\ViewHelperFactory::PROJECT_LIST,
                Application\View\Helper\ViewHelperFactory::PROJECT_TOOLBAR,
                Application\View\Helper\ViewHelperFactory::PROJECT_SIDEBAR,
            ],
            Application\View\Helper\ViewHelperFactory::class
        )
    ),
    'input_filters' => array(
        'factories'  => array(
            'project_filter'  => function ($manager) {
                return new \Projects\Filter\Project($manager->get('p4_admin'), $manager->get('p4_user'));
            },
        ),
    ),
);
